services

package
v0.0.14 Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: Apr 7, 2026 License: MIT Imports: 25 Imported by: 0

Documentation

Index

Constants

const CONFIG_SVC = "config_svc"
const DATASTREAM_SVC = "datastream_svc"
const FLUXRPC_SVC = "fluxrpc_svc"
const RUGCHECK_SVC = "rugcheck_svc"
const YELLOWSTONE_SVC = "yellowstone_svc"

Variables

This section is empty.

Functions

func ResolveRPCBaseURL

func ResolveRPCBaseURL(cfg *dto.FluxRPCConfig) string

ResolveRPCBaseURL returns the base URL for the configured region. Region takes precedence over base_url if set.

func ResolveYellowstoneURL added in v0.0.6

func ResolveYellowstoneURL(cfg *dto.FluxRPCConfig) string

Types

type ConfigService

type ConfigService struct {
	context.DefaultService
	// contains filtered or unexported fields
}

func (*ConfigService) Config

func (s *ConfigService) Config() *dto.Config

func (*ConfigService) ConfigPath

func (s *ConfigService) ConfigPath() string

func (*ConfigService) Configure

func (s *ConfigService) Configure(ctx *context.Context) error

func (*ConfigService) Exists added in v0.0.10

func (s *ConfigService) Exists() bool

func (*ConfigService) Get

func (s *ConfigService) Get(key string) (string, error)

Get retrieves a config value by dot-notation key.

func (*ConfigService) Id

func (s *ConfigService) Id() string

func (*ConfigService) List

func (s *ConfigService) List() map[string]interface{}

List returns a redacted copy of the config suitable for display.

func (*ConfigService) SaveConfig added in v0.0.10

func (s *ConfigService) SaveConfig(cfg dto.Config) error

func (*ConfigService) Set

func (s *ConfigService) Set(key, value string) error

Set updates a config value by dot-notation key (e.g. "datastream.api_key").

type DataStreamService

type DataStreamService struct {
	context.DefaultService

	Client *httpclient.Client
}

func (*DataStreamService) Configure

func (s *DataStreamService) Configure(ctx *context.Context) error

func (*DataStreamService) GetBulkCandles

func (s *DataStreamService) GetBulkCandles(ids string, interval string, from, to int64, count int) (interface{}, error)

GetBulkCandles returns bulk candle data for multiple tokens.

func (*DataStreamService) GetPrices

func (s *DataStreamService) GetPrices(ids string) (interface{}, error)

GetPrices returns bulk token prices for the given comma-separated mint IDs.

func (*DataStreamService) GetStatsNew

func (s *DataStreamService) GetStatsNew() (interface{}, error)

GetStatsNew returns newly detected tokens.

func (*DataStreamService) GetStatsTop

func (s *DataStreamService) GetStatsTop(limit int, interval string) (interface{}, error)

GetStatsTop returns top tokens by volume.

func (*DataStreamService) GetStatsTrending

func (s *DataStreamService) GetStatsTrending(limit int, interval string) (interface{}, error)

GetStatsTrending returns trending tokens.

func (*DataStreamService) GetStatsVolume

func (s *DataStreamService) GetStatsVolume(limit int) (interface{}, error)

GetStatsVolume returns tokens by volume.

func (*DataStreamService) GetToken

func (s *DataStreamService) GetToken(id string) (interface{}, error)

GetToken returns details for a specific token.

func (*DataStreamService) GetTokenCandles

func (s *DataStreamService) GetTokenCandles(id string, interval string, from, to int64, count int) (interface{}, error)

GetTokenCandles returns OHLCV candle data for a token.

func (*DataStreamService) GetTokenDetails

func (s *DataStreamService) GetTokenDetails(id string) (interface{}, error)

GetTokenDetails returns extended token info with price and market cap.

func (*DataStreamService) GetTokenHolders

func (s *DataStreamService) GetTokenHolders(id string, limit, page int) (interface{}, error)

GetTokenHolders returns holders for a token.

func (*DataStreamService) GetTokenHoldersCount

func (s *DataStreamService) GetTokenHoldersCount(id string) (interface{}, error)

GetTokenHoldersCount returns the holder count for a token.

func (*DataStreamService) GetTokenHoldersDistribution

func (s *DataStreamService) GetTokenHoldersDistribution(id string) (interface{}, error)

GetTokenHoldersDistribution returns holder distribution for a token.

func (*DataStreamService) GetTokenHoldersTop

func (s *DataStreamService) GetTokenHoldersTop(id string, limit int) (interface{}, error)

GetTokenHoldersTop returns top holders for a token.

func (*DataStreamService) GetTokenMcap

func (s *DataStreamService) GetTokenMcap(id string) (interface{}, error)

GetTokenMcap returns the market cap for a token.

func (*DataStreamService) GetTokenPrice

func (s *DataStreamService) GetTokenPrice(id string) (interface{}, error)

GetTokenPrice returns the current price for a token.

func (*DataStreamService) GetTokenStats

func (s *DataStreamService) GetTokenStats(id string) (interface{}, error)

GetTokenStats returns volume change stats for a token.

func (*DataStreamService) GetTokenTraders

func (s *DataStreamService) GetTokenTraders(id string, limit, page int, all bool) (interface{}, error)

GetTokenTraders returns trader stats for a token.

func (*DataStreamService) GetTokenTrades

func (s *DataStreamService) GetTokenTrades(id string, limit int, from, to int64) (interface{}, error)

GetTokenTrades returns trade history for a token.

func (*DataStreamService) GetTokens

func (s *DataStreamService) GetTokens(cursor string, limit int) (interface{}, error)

GetTokens returns a paginated list of tokens.

func (*DataStreamService) GetTraderDetail

func (s *DataStreamService) GetTraderDetail(id string) (interface{}, error)

GetTraderDetail returns details for a specific trader.

func (*DataStreamService) GetTraderPnL

func (s *DataStreamService) GetTraderPnL(id string, limit int) (interface{}, error)

GetTraderPnL returns PnL for a trader.

func (*DataStreamService) GetTraderTokens

func (s *DataStreamService) GetTraderTokens(id string, limit int) (interface{}, error)

GetTraderTokens returns token holdings for a trader.

func (*DataStreamService) GetTraderTrades

func (s *DataStreamService) GetTraderTrades(id string, limit int, from, to int64) (interface{}, error)

GetTraderTrades returns trade history for a trader.

func (*DataStreamService) GetTradersTop

func (s *DataStreamService) GetTradersTop(limit int, from, to int64) (interface{}, error)

GetTradersTop returns top traders.

func (*DataStreamService) Id

func (s *DataStreamService) Id() string

type FluxRPCService

type FluxRPCService struct {
	context.DefaultService

	Client *httpclient.Client
}

func (*FluxRPCService) Call

func (s *FluxRPCService) Call(method string, params []interface{}) (interface{}, error)

Call executes an arbitrary JSON-RPC method.

func (*FluxRPCService) Configure

func (s *FluxRPCService) Configure(ctx *context.Context) error

func (*FluxRPCService) GetAccountInfo

func (s *FluxRPCService) GetAccountInfo(pubkey string, encoding string, commitment string) (interface{}, error)

func (*FluxRPCService) GetBalance

func (s *FluxRPCService) GetBalance(pubkey string, commitment string) (interface{}, error)

func (*FluxRPCService) GetBlock

func (s *FluxRPCService) GetBlock(slot uint64, encoding string, txDetail string, commitment string) (interface{}, error)

func (*FluxRPCService) GetBlockCommitment

func (s *FluxRPCService) GetBlockCommitment(slot uint64) (interface{}, error)

func (*FluxRPCService) GetBlockHeight

func (s *FluxRPCService) GetBlockHeight(commitment string) (interface{}, error)

func (*FluxRPCService) GetBlockProduction

func (s *FluxRPCService) GetBlockProduction(identity string, commitment string) (interface{}, error)

func (*FluxRPCService) GetBlockTime

func (s *FluxRPCService) GetBlockTime(slot uint64) (interface{}, error)

func (*FluxRPCService) GetBlocks

func (s *FluxRPCService) GetBlocks(startSlot, endSlot uint64, commitment string) (interface{}, error)

func (*FluxRPCService) GetBlocksWithLimit

func (s *FluxRPCService) GetBlocksWithLimit(startSlot, limit uint64, commitment string) (interface{}, error)

func (*FluxRPCService) GetClusterNodes

func (s *FluxRPCService) GetClusterNodes() (interface{}, error)

func (*FluxRPCService) GetEpochInfo

func (s *FluxRPCService) GetEpochInfo(commitment string) (interface{}, error)

func (*FluxRPCService) GetEpochSchedule

func (s *FluxRPCService) GetEpochSchedule() (interface{}, error)

func (*FluxRPCService) GetFeeForMessage

func (s *FluxRPCService) GetFeeForMessage(message string, commitment string) (interface{}, error)

func (*FluxRPCService) GetFirstAvailableBlock

func (s *FluxRPCService) GetFirstAvailableBlock() (interface{}, error)

func (*FluxRPCService) GetGenesisHash

func (s *FluxRPCService) GetGenesisHash() (interface{}, error)

func (*FluxRPCService) GetHealth

func (s *FluxRPCService) GetHealth() (interface{}, error)

func (*FluxRPCService) GetHighestSnapshotSlot

func (s *FluxRPCService) GetHighestSnapshotSlot() (interface{}, error)

func (*FluxRPCService) GetIdentity

func (s *FluxRPCService) GetIdentity() (interface{}, error)

func (*FluxRPCService) GetInflationGovernor

func (s *FluxRPCService) GetInflationGovernor(commitment string) (interface{}, error)

func (*FluxRPCService) GetInflationRate

func (s *FluxRPCService) GetInflationRate() (interface{}, error)

func (*FluxRPCService) GetInflationReward

func (s *FluxRPCService) GetInflationReward(addresses []string, epoch uint64, commitment string) (interface{}, error)

func (*FluxRPCService) GetLargestAccounts

func (s *FluxRPCService) GetLargestAccounts(filter string, commitment string) (interface{}, error)

func (*FluxRPCService) GetLatestBlockhash

func (s *FluxRPCService) GetLatestBlockhash(commitment string) (interface{}, error)

func (*FluxRPCService) GetLeaderSchedule

func (s *FluxRPCService) GetLeaderSchedule(slot uint64, identity string, commitment string) (interface{}, error)

func (*FluxRPCService) GetMaxRetransmitSlot

func (s *FluxRPCService) GetMaxRetransmitSlot() (interface{}, error)

func (*FluxRPCService) GetMaxShredInsertSlot

func (s *FluxRPCService) GetMaxShredInsertSlot() (interface{}, error)

func (*FluxRPCService) GetMinimumBalanceForRentExemption

func (s *FluxRPCService) GetMinimumBalanceForRentExemption(dataLength uint64, commitment string) (interface{}, error)

func (*FluxRPCService) GetMultipleAccounts

func (s *FluxRPCService) GetMultipleAccounts(pubkeys []string, encoding string, commitment string) (interface{}, error)

func (*FluxRPCService) GetProgramAccounts

func (s *FluxRPCService) GetProgramAccounts(programId string, encoding string, filters string, commitment string) (interface{}, error)

func (*FluxRPCService) GetRecentPerformanceSamples

func (s *FluxRPCService) GetRecentPerformanceSamples(limit int) (interface{}, error)

func (*FluxRPCService) GetRecentPrioritizationFees

func (s *FluxRPCService) GetRecentPrioritizationFees(addresses []string) (interface{}, error)

func (*FluxRPCService) GetSignatureStatuses

func (s *FluxRPCService) GetSignatureStatuses(signatures []string, searchHistory bool) (interface{}, error)

func (*FluxRPCService) GetSignaturesForAddress

func (s *FluxRPCService) GetSignaturesForAddress(address string, limit int, before, until, commitment string) (interface{}, error)

func (*FluxRPCService) GetSlot

func (s *FluxRPCService) GetSlot(commitment string) (interface{}, error)

func (*FluxRPCService) GetSlotLeader

func (s *FluxRPCService) GetSlotLeader(commitment string) (interface{}, error)

func (*FluxRPCService) GetSlotLeaders

func (s *FluxRPCService) GetSlotLeaders(startSlot, limit uint64) (interface{}, error)

func (*FluxRPCService) GetStakeMinimumDelegation

func (s *FluxRPCService) GetStakeMinimumDelegation(commitment string) (interface{}, error)

func (*FluxRPCService) GetSupply

func (s *FluxRPCService) GetSupply(commitment string) (interface{}, error)

func (*FluxRPCService) GetTokenAccountBalance

func (s *FluxRPCService) GetTokenAccountBalance(pubkey string, commitment string) (interface{}, error)

func (*FluxRPCService) GetTokenAccountsByDelegate

func (s *FluxRPCService) GetTokenAccountsByDelegate(delegate string, filterKey, filterValue string, encoding string, commitment string) (interface{}, error)

func (*FluxRPCService) GetTokenAccountsByOwner

func (s *FluxRPCService) GetTokenAccountsByOwner(owner string, filterKey, filterValue string, encoding string, commitment string) (interface{}, error)

func (*FluxRPCService) GetTokenLargestAccounts

func (s *FluxRPCService) GetTokenLargestAccounts(mint string, commitment string) (interface{}, error)

func (*FluxRPCService) GetTokenSupply

func (s *FluxRPCService) GetTokenSupply(mint string, commitment string) (interface{}, error)

func (*FluxRPCService) GetTransaction

func (s *FluxRPCService) GetTransaction(signature string, encoding string, commitment string) (interface{}, error)

func (*FluxRPCService) GetTransactionCount

func (s *FluxRPCService) GetTransactionCount(commitment string) (interface{}, error)

func (*FluxRPCService) GetVersion

func (s *FluxRPCService) GetVersion() (interface{}, error)

func (*FluxRPCService) GetVoteAccounts

func (s *FluxRPCService) GetVoteAccounts(votePubkey string, commitment string) (interface{}, error)

func (*FluxRPCService) Id

func (s *FluxRPCService) Id() string

func (*FluxRPCService) IsBlockhashValid

func (s *FluxRPCService) IsBlockhashValid(blockhash string, commitment string) (interface{}, error)

func (*FluxRPCService) MinimumLedgerSlot

func (s *FluxRPCService) MinimumLedgerSlot() (interface{}, error)

func (*FluxRPCService) RequestAirdrop

func (s *FluxRPCService) RequestAirdrop(pubkey string, lamports uint64, commitment string) (interface{}, error)

func (*FluxRPCService) SendTransaction

func (s *FluxRPCService) SendTransaction(tx string, encoding string, skipPreflight bool, commitment string) (interface{}, error)

func (*FluxRPCService) SimulateTransaction

func (s *FluxRPCService) SimulateTransaction(tx string, encoding string, sigVerify bool, commitment string) (interface{}, error)

type RugCheckService

type RugCheckService struct {
	context.DefaultService

	Client *httpclient.Client
}

func (*RugCheckService) Configure

func (s *RugCheckService) Configure(ctx *context.Context) error

func (*RugCheckService) GetChains

func (s *RugCheckService) GetChains() (interface{}, error)

GetChains returns all supported chains.

func (*RugCheckService) GetReport

func (s *RugCheckService) GetReport(mint string) (interface{}, error)

GetReport returns a detailed security report for a token.

func (*RugCheckService) GetStatsNew

func (s *RugCheckService) GetStatsNew() (interface{}, error)

GetStatsNew returns recently detected tokens.

func (*RugCheckService) GetStatsRecent

func (s *RugCheckService) GetStatsRecent() (interface{}, error)

GetStatsRecent returns most viewed tokens.

func (*RugCheckService) GetStatsTrending

func (s *RugCheckService) GetStatsTrending() (interface{}, error)

GetStatsTrending returns trending tokens.

func (*RugCheckService) GetStatsVerified

func (s *RugCheckService) GetStatsVerified() (interface{}, error)

GetStatsVerified returns verified tokens.

func (*RugCheckService) GetSummary

func (s *RugCheckService) GetSummary(mint string) (interface{}, error)

GetSummary returns a summary security report for a token.

func (*RugCheckService) GetWalletRisk

func (s *RugCheckService) GetWalletRisk(chain, walletAddress string) (interface{}, error)

GetWalletRisk returns a wallet risk assessment.

func (*RugCheckService) Id

func (s *RugCheckService) Id() string

func (*RugCheckService) Scan

func (s *RugCheckService) Scan(chain, contractAddress string, includeDexScreener bool) (interface{}, error)

Scan performs a real-time token security scan.

func (*RugCheckService) Search

func (s *RugCheckService) Search(query, chain string, pageSize int) (interface{}, error)

Search searches tokens by name or symbol.

type YellowstoneService added in v0.0.6

type YellowstoneService struct {
	ctxpkg.DefaultService
	// contains filtered or unexported fields
}

func (*YellowstoneService) Configure added in v0.0.6

func (s *YellowstoneService) Configure(ctx *ctxpkg.Context) error

func (*YellowstoneService) Id added in v0.0.6

func (s *YellowstoneService) Id() string

func (*YellowstoneService) Shutdown added in v0.0.6

func (s *YellowstoneService) Shutdown()

func (*YellowstoneService) WatchAccounts added in v0.0.6

func (s *YellowstoneService) WatchAccounts(ctx stdcontext.Context, accounts []string, commitment pb.CommitmentLevel, onUpdate func(*pb.SubscribeUpdate) error) error

func (*YellowstoneService) WatchProgramOwners added in v0.0.6

func (s *YellowstoneService) WatchProgramOwners(ctx stdcontext.Context, owners []string, commitment pb.CommitmentLevel, onUpdate func(*pb.SubscribeUpdate) error) error

func (*YellowstoneService) WatchSlots added in v0.0.6

func (s *YellowstoneService) WatchSlots(ctx stdcontext.Context, commitment pb.CommitmentLevel, interslotUpdates bool, onUpdate func(*pb.SubscribeUpdate) error) error

func (*YellowstoneService) WatchTransactionSignature added in v0.0.6

func (s *YellowstoneService) WatchTransactionSignature(
	ctx stdcontext.Context,
	signature string,
	commitment pb.CommitmentLevel,
	onUpdate func(*pb.SubscribeUpdate) error,
) error

func (*YellowstoneService) WatchTransactions added in v0.0.6

func (s *YellowstoneService) WatchTransactions(
	ctx stdcontext.Context,
	accountInclude []string,
	accountExclude []string,
	accountRequired []string,
	includeVotes bool,
	includeFailed bool,
	commitment pb.CommitmentLevel,
	onUpdate func(*pb.SubscribeUpdate) error,
) error

Jump to