Documentation
¶
Index ¶
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
This section is empty.
Types ¶
type Context ¶
type Context struct {
// contains filtered or unexported fields
}
Context is a small service wrapper that handles the startup/shutdown of services.
type DefaultService ¶
type DefaultService struct {
// contains filtered or unexported fields
}
DefaultService should be extended for each service. Handles the internal context routing.
func (*DefaultService) Configure ¶
func (ds *DefaultService) Configure(ctx *Context) error
Configure is the base that will be called for EVERY service extending DefaultService.
func (*DefaultService) Service ¶
func (ds *DefaultService) Service(id string) Service
Service returns the inner context service by ID.
func (*DefaultService) Services ¶
func (ds *DefaultService) Services() []string
Services returns the inner context list of service keys.
func (*DefaultService) Shutdown ¶
func (ds *DefaultService) Shutdown()
Shutdown performs any shutdown procedures.
Click to show internal directories.
Click to hide internal directories.